@@ -3,9 +3,9 @@ from typing import Any, List
 
 class _MISSING:
     def __repr__(self) -> str:
-        return ". . ."
+        return "..."
     def __eq__(self, o: object) -> bool:
-        return isinstance(o, self)
+        return isinstance(o, _MISSING)
     def __ne__(self, o: object) -> bool:
         return not self.__eq__(o)
     def __str__(self) -> str:
@@ -146,9 +146,9 @@ def components_to_dict(*components) -> List[dict]:
         wrappers = [components]
 
     for wrap in wrappers:
-        if not all(hasattr(x, "to_dict") for x in wrap):
+        if type(wrap) is list and not all(hasattr(x, "to_dict") for x in wrap):
             raise Exception("Components with types [" + ', '.join([str(type(x)) for x in wrap]) + "] are missing to_dict() method")
-        component_list.append({"type": 1, "components": [x.to_dict() for x in wrap]})
+        component_list.append({"type": 1, "components": [x.to_dict() for x in wrap] if type(wrap) is list else [wrap.to_dict()]})
     return component_list
 
 def setup_logger(name):
